/*
 * Copyright (c) 2007 Dmitry S. Baikov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

#ifndef __jack_alsa_midi_impl_h__
#define __jack_alsa_midi_impl_h__


#ifdef JACKMP

#include "types.h"

#ifdef __cplusplus
extern "C" {
#endif

//typedef void* JACK_client_t;
typedef int JACK_port_t;
enum { JACK_INVALID_PORT=-1 };

int JACK_is_realtime(JACK_client_t client);
int JACK_create_thread(JACK_client_t client, pthread_t *thread, int priority, int realtime, void *(*start_routine)(void*), void *arg);

JACK_port_t JACK_port_register(JACK_client_t client, const char *port_name, const char *port_type, unsigned long flags, unsigned long buffer_size);
int JACK_port_unregister(JACK_client_t , JACK_port_t);
void* JACK_port_get_buffer(JACK_client_t client, JACK_port_t, jack_nframes_t);

jack_nframes_t JACK_get_sample_rate(JACK_client_t);
jack_nframes_t JACK_frame_time(JACK_client_t );
jack_nframes_t JACK_last_frame_time(JACK_client_t);

#ifdef __cplusplus
} // extern "C"
#endif

#else // usual jack

#include <jack/jack.h>
#include <jack/thread.h>

//typedef jack_client_t* JACK_client_t;
typedef jack_port_t* JACK_port_t;
#define JACK_INVALID_PORT NULL

#define JACK_is_realtime jack_is_realtime
#define JACK_create_thread jack_client_create_thread

#define JACK_port_register jack_port_register
#define JACK_port_unregister jack_port_unregister
#define JACK_port_get_buffer(c,p,n) jack_port_get_buffer(p,n)

#define JACK_get_sample_rate jack_get_sample_rate
#define JACK_frame_time jack_frame_time
#define JACK_last_frame_time jack_last_frame_time

#endif


#if defined(STANDALONE) || defined(JACKMP)
#define MESSAGE(...) fprintf(stderr, __VA_ARGS__)
#else
#include <jack/messagebuffer.h>
#endif

#define info_log(...)  MESSAGE(__VA_ARGS__)
#define error_log(...) MESSAGE(__VA_ARGS__)

#ifdef DEBUG
#define debug_log(...) MESSAGE(__VA_ARGS__)
#else
#define debug_log(...)
#endif

#define NSEC_PER_SEC ((int64_t)1000*1000*1000)


#include "alsa_midi.h"


#endif /* __jack_alsa_midi_impl_h__ */
